==> openjdk-17_17.0.17+10.orig.tar.xz: openjdk-17-17.0.17+10/test/langtools/tools/javac/processing/6994946/TestProcessor.java <==
/*
 * Copyright (c) 2010, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import java.util.*;
import javax.annotation.processing.*;
import javax.lang.model.*;
import javax.lang.model.element.*;
import static javax.tools.Diagnostic.Kind.*;

import com.sun.source.util.TreePath;
import com.sun.source.util.Trees;

public class TestProcessor extends JavacTestingAbstractProcessor {
   private int round = 0;

   public boolean process(Set<? extends TypeElement> annotations,
                  RoundEnvironment roundEnv) {
        if (++round == 1) {
            messager.printMessage(ERROR, "Deliberate Error");
            Trees trees = Trees.instance(processingEnv);
            TreePath elPath = trees.getPath(roundEnv.getRootElements().iterator().next());
            trees.printMessage(ERROR, "Deliberate Error on Trees",
                               elPath.getLeaf(), elPath.getCompilationUnit());
        }
        return false;
   }
}

==> openjdk-24_24+36.orig.tar.xz: openjdk-24-24+36/test/langtools/tools/javac/processing/6994946/TestProcessor.java <==
/*
 * Copyright (c) 2010, 2021, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import java.util.*;
import javax.annotation.processing.*;
import javax.lang.model.*;
import javax.lang.model.element.*;
import static javax.tools.Diagnostic.Kind.*;

import com.sun.source.util.TreePath;
import com.sun.source.util.Trees;

public class TestProcessor extends JavacTestingAbstractProcessor {
   private int round = 0;

   public boolean process(Set<? extends TypeElement> annotations,
                  RoundEnvironment roundEnv) {
        if (++round == 1) {
            messager.printError("Deliberate Error");
            Trees trees = Trees.instance(processingEnv);
            TreePath elPath = trees.getPath(roundEnv.getRootElements().iterator().next());
            trees.printMessage(ERROR, "Deliberate Error on Trees",
                               elPath.getLeaf(), elPath.getCompilationUnit());
        }
        return false;
   }
}
